@@ -49,6 +49,7 @@ class accuinsight(object):
         self.token = None
         self.channel_id = None
         self.message = None
+        self.feature_name = None
 
     def get_file(self, storage_json_file_name):
         
@@ -156,9 +157,24 @@ class accuinsight(object):
             self.message = message
             self.thresholds = thresholds
 
+    def set_features(self, feature_names):
+        
+        if str(type(feature_names)) == "<class 'list'>":
+            self.feature_name = feature_names
+        else:
+            try:
+                self.feature_name = feature_names.tolist()
+            except:
+                pass
+            
+            try:
+                self.feature_name = list(feature_names)
+            except AttributeError:
+                raise ValueError('입력값으로 list 또는 pandas.core.indexes.base.Index를 사용하시기 바랍니다.')
+                
+
     def autolog(self, tag=None, best_weights = False, model_monitor=False):
-        global description, endpoint, var_model_file_path, message, thresholds, token, channel_id, best_weights_on, \
-               feature_name, run_id, shap_on
+        global description, endpoint, var_model_file_path, message, thresholds, token, channel_id, best_weights_on, run_id, shap_on, feature_name
         description = tag
         endpoint = self.endpoint
         message = self.message
@@ -172,10 +188,17 @@ class accuinsight(object):
             best_weights_on = False
         if model_monitor == True:
             shap_on = True
-            try:
-                feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
-            except:
-                feature_name = None      # when user did not use <get_file> function
+            if self.feature_name is None:
+                try:
+                    feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
+                    
+                    print('1: ', feature_name)
+                    
+                except:
+                    pass      # when user did not use <get_file> or <set_feature> function
+            else:
+                print('2: ', self.feature_name)
+                feature_name = self.feature_name
         else:
             shap_on = False
         run_id = None
@@ -417,18 +440,12 @@ class accuinsight(object):
                 self.trainX = trainX
                 self.trigger = shap_on
                 self.run_id = run_id
-                #if feature_name is not None:
-                #    self.feature_name = feature_name
-                #else:
-                self.feature_name = feature_name
-                
+                self.feature_name_in_shap = feature_name
+
 
             def on_train_end(self, logs={}):
                 if self.trigger:
-                    self.shap_value = shap_value(self.model, self.trainX, self.feature_name)
-                
-#                    print('shap_value')   ##################
-#                    print(self.shap_value)   ##################
+                    self.shap_value = shap_value(self.model, self.trainX, self.feature_name_in_shap)
                     
 #                     func.insertDB(self.shap_value, 2)  # 수정: 2 -> self.run_id
                     
